summaryrefslogtreecommitdiff
path: root/libpod/options.go
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2020-01-29 14:01:52 -0800
committerGitHub <noreply@github.com>2020-01-29 14:01:52 -0800
commiteb283657036f5dc69c926432252768d158989100 (patch)
tree8863767789f946b185e074b032dce2fc0d686385 /libpod/options.go
parent0e21fc88604fd2fc12fbbbf5d0f162081aa5dda2 (diff)
parent5d93c731afd5b21d88c025069da0e82455f09445 (diff)
downloadpodman-eb283657036f5dc69c926432252768d158989100.tar.gz
podman-eb283657036f5dc69c926432252768d158989100.tar.bz2
podman-eb283657036f5dc69c926432252768d158989100.zip
Merge pull request #5018 from mheon/new_anon_field
Deprecate & remove IsCtrSpecific in favor of IsAnon
Diffstat (limited to 'libpod/options.go')
-rw-r--r--libpod/options.go11
1 files changed, 5 insertions, 6 deletions
diff --git a/libpod/options.go b/libpod/options.go
index 593037382..923e7292c 100644
--- a/libpod/options.go
+++ b/libpod/options.go
@@ -1546,17 +1546,16 @@ func WithVolumeGID(gid int) VolumeCreateOption {
}
}
-// withSetCtrSpecific sets a bool notifying libpod that a volume was created
-// specifically for a container.
-// These volumes will be removed when the container is removed and volumes are
-// also specified for removal.
-func withSetCtrSpecific() VolumeCreateOption {
+// withSetAnon sets a bool notifying libpod that this volume is anonymous and
+// should be removed when containers using it are removed and volumes are
+// specified for removal.
+func withSetAnon() VolumeCreateOption {
return func(volume *Volume) error {
if volume.valid {
return define.ErrVolumeFinalized
}
- volume.config.IsCtrSpecific = true
+ volume.config.IsAnon = true
return nil
}